

import { useNavigate } from "react-router-dom";
import React, { useEffect, useState } from "react";
import axios from "axios";
import './index.css';
import { Header } from "../../Components/Header";
import { ImageSlide2 } from "../../Components/imageslide2";
import { Footer } from "../../Components/footer";

// breadcrums images
import image from "../../Assests/Images/darkbread.jpg";
import image2 from "../../Assests/Images/line.png";
import image3 from "../../Assests/Images/sprade-light.png";

//bread-crums image end

export const CartPage = () => {
    const [carts, setCarts] = useState([]);
    const navigate = useNavigate();
    const [user, setUser] = useState(null);

    useEffect(() => {
        const storedUser = JSON.parse(localStorage.getItem("user"));
        if (storedUser) {
            setUser(storedUser);
        }
    }, []);




    useEffect(() => {
        const token = localStorage.getItem("token");
        if (!token) {
            navigate("/login");
            return;
        }

        const fetchCarts = async () => {
            try {
                const response = await axios.get(`http://localhost:8000/api/carts/${user.id}`, {
                    headers: { Authorization: `Bearer ${token}` }
                });
                if (response?.data?.success) {
                    const cartData = response.data.data.map(item => ({
                        ...item,
                        quantity: item.quantity || 1
                    }));
                    
                    setCarts(cartData);
                }
            } catch (error) {
                console.error("Error fetching carts:", error);
            }
        };

        fetchCarts();
    }, [user,navigate]);

        const handleRemove = async (id) => {
        try {
            const token = localStorage.getItem("token");
            const response = await axios.delete(`http://localhost:8000/api/carts/${id}`, {
                headers: {
                    Authorization: `Bearer ${token}`,
                }
            });

            if (response.data.success) {
                // Remove item from state
                setCarts(prev => prev.filter(item => item.id !== id));
            }
        } catch (error) {
            console.error("Failed to delete wishlist item:", error);
        }
    };


    const handleQuantityChange = async (id, delta) => {
        const updatedCarts = carts.map(item => {
            if (item.id === id) {
                const newQuantity = Math.max(1, item.quantity + delta);
                return { ...item, quantity: newQuantity };
            }
            return item;
        });
        setCarts(updatedCarts);

        const updatedItem = updatedCarts.find(item => item.id === id);

        try {
            const token = localStorage.getItem("token");
            await axios.put(`http://localhost:8000/api/carts/${id}`, {
                quantity: updatedItem.quantity
            }, {
                headers: { Authorization: `Bearer ${token}` }
            });
        } catch (error) {
            console.error("Failed to update cart quantity:", error);
        }
    };

    


    return (
        <>
            <div className="donationpage">
                <Header />
                {/* breadcrums code */}
                <div className="breadcrums">
                     <div className="breadcrums-imgbx">
                         <img src={image} alt="" />
                     </div>
                     <div className="breadcrums-content">
                         <h1>Carts</h1>
                     </div>

                     <div className="breadcrums-front-img">
                         <img src={image2} alt="" />
                     </div>

                     <div className="stiker">
                         <img src={image3} alt="" />
                     </div>

                     <div className="bread-crums-main-content">
                         <div className="sub-content">
                             <a href="">Home</a>
                             <span>/</span>
                             <a href="">Carts</a>
                         </div>
                     </div>
                 </div>

                <div style={{ padding: "0 10%", marginBottom: "50px" }}>
                    <div className="aid-control">
                        <h1>My Orders</h1>

                        {carts.length === 0 ? (
                            <div style={{ textAlign: "center", padding: "50px" }}>
                                <h2>No Products Found</h2>
                            </div>
                        ) : (
                            <table style={{ minHeight: "300px" }}>
                                <thead>
                                    <tr>
                                        <th style={{ textAlign: "center" }}>SL No</th>
                                        <th style={{ textAlign: "center" }}>Product Name</th>
                                        <th style={{ textAlign: "center" }}>Price</th>
                                        <th style={{ textAlign: "center" }}>Quantity</th>
                                        <th> Image</th>
                                        <th style={{ textAlign: "center" }}>Final Price</th>
                                        <th style={{ textAlign: "center" }}> Actions</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    {carts.map((item, index) => (
                                        <tr key={item.id}>
                                            <td style={{ textAlign: "center" }}>{index + 1}</td>
                                            <td style={{ textAlign: "center" }}>{item.product?.title || "N/A"}</td>
                                            <td style={{ textAlign: "center" }}>{item.product?.price ? `৳${item.product.price}` : "N/A"}</td>
                                            <td style={{ textAlign: "center" }}>
                                                <button onClick={() => handleQuantityChange(item.id, -1)} className="update-btn">-</button>
                                                <span style={{ margin: "0 10px" }}>{item.quantity}</span>
                                                <button onClick={() => handleQuantityChange(item.id, 1)} className="update-btn">+</button>
                                            </td>
                                            <td style={{ textAlign: "center" }}>
                                                {item.product?.image ? (
                                                    <img
                                                        src={`http://localhost:8000/${item.product.image}`}
                                                        alt={item.product.title}
                                                        style={{ width: "70px", height: "70px", objectFit: "cover" }}
                                                    />
                                                ) : (
                                                    "No Image"
                                                )}
                                            </td>
                                            <td style={{ textAlign: "center" }}>
                                                ৳{item.product?.price ? (item.quantity * item.product.price).toFixed(2) : "0.00"}
                                            </td>
                                            <td style={{ textAlign: "center" }}>
                                                <button className="btn btn-danger" onClick={() => {
                                                    if (window.confirm("Are you sure you want to remove this item?")) {
                                                        handleRemove(item.id);
                                                    }
                                                }}>Remove</button>
                                            </td>
                                        </tr>
                                    ))}
                                </tbody>
                            </table>
                        )}
                    </div>
                </div>
                <ImageSlide2 />
                <Footer />
            </div>
        </>
    );
};
